@@ -41,6 +41,7 @@ import univention.admin.mapping
 import univention.admin.syntax
 import univention.admin.nagios as nagios
 from univention.admin.handlers.computers.__base import ComputerObject
+from univention.admin.certificate import register_pki_integration
 
 translation = univention.admin.localization.translation('univention.admin.handlers.computers')
 _ = translation.translate
@@ -74,7 +75,7 @@ options = {
 		editable=True,
 		default=1,
 		objectClasses=('sambaSamAccount',),
-	)
+	),
 }
 property_descriptions = {
 	'name': univention.admin.property(
@@ -303,6 +304,7 @@ mapping.register('operatingSystemVersion', 'univentionOperatingSystemVersion', N
 
 # add Nagios extension
 nagios.addPropertiesMappingOptionsAndLayout(property_descriptions, mapping, options, layout)
+register_pki_integration(property_descriptions, mapping, options, layout)
 
 
 class object(ComputerObject):
