@@ -36,11 +36,13 @@
 
 from __future__ import absolute_import
 
+import builtins
 import calendar
 import copy
 import os
 import re
 import time
+import warnings
 from datetime import datetime
 
 import ldap
@@ -1111,6 +1113,8 @@ mapping.register('password', 'userPassword', univention.admin.mapping.dontMap(),
 register_pki_integration(property_descriptions, mapping, options, layout)
 default_property_descriptions = copy.deepcopy(property_descriptions)  # for later reset of descriptions
 
+_sentinel = builtins.object()
+
 
 class object(univention.admin.handlers.simpleLdap, PKIIntegration):
 	module = module
@@ -1118,7 +1122,7 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
 	use_performant_ldap_search_filter = True
 
 	def __init__(self, co, lo, position, dn=u'', superordinate=None, attributes=None):
-		self.groupsLoaded = True
+		self.__groups_loaded = True
 		self.password_length = 8
 
 		univention.admin.handlers.simpleLdap.__init__(self, co, lo, position, dn, superordinate, attributes=attributes)
@@ -1143,11 +1147,16 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
 
 	def _post_unmap(self, info, values):
 		info = super(object, self)._post_unmap(info, values)
+		if configRegistry.is_true('directory/manager/user/group-memberships-via-memberof', True):
+			info['groups'] = [x.decode('UTF-8') for x in values.get('memberOf', [])]
+			self.__groups_loaded = True
 		self._unmap_mail_forward(info, values)
 		self._unmap_pwd_change_next_login(info, values)
 		return info
 
-	def open(self, loadGroups=True):
+	def open(self, loadGroups=_sentinel):
+		if loadGroups is not _sentinel:
+			warnings.warn('UDM users/user:open() called with deprecated loadGroups!', DeprecationWarning)
 		univention.admin.handlers.simpleLdap.open(self)
 		self.pki_open()
 		if self.exists():
@@ -1163,11 +1172,13 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
 			self._set_default_group()
 
 	def _load_groups(self, loadGroups):
+		if configRegistry.is_true('directory/manager/user/group-memberships-via-memberof', True):
+			return
 		if loadGroups:  # this is optional because it can take much time on larger installations, default is true
 			self['groups'] = [x.decode('UTF-8') if six.PY2 else x for x in self.lo.searchDn(filter=filter_format(u'(&(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping))(uniqueMember=%s))', [self.dn]))]
 		else:  # TODO: document where it is needed and used
 			ud.debug(ud.ADMIN, ud.INFO, 'user: open with loadGroups=false for user %s' % (self['username'],))
-		self.groupsLoaded = loadGroups
+		self.__groups_loaded = bool(loadGroups)
 
 	def _unmap_gid_number(self):
 		primaryGroupNumber = self.oldattr.get('gidNumber', [b''])[0].decode('ASCII')
@@ -1325,7 +1336,7 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
 #		return super(object, self).hasChanged(key)
 
 	def __update_groups(self):
-		if not self.groupsLoaded:
+		if not self.__groups_loaded:
 			return
 
 		if self.exists():
@@ -2043,7 +2054,7 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
 
 	@classmethod
 	def _ldap_attributes(cls):
-		return super(object, cls)._ldap_attributes() + ['pwdAccountLockedTime']
+		return super(object, cls)._ldap_attributes() + ['pwdAccountLockedTime', 'memberOf']
 
 	@classmethod
 	def rewrite_filter(cls, filter, mapping):
